@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -26,7 +26,6 @@
 #include <sstream>
 #include <string>
 
-#include <guichan/sdl/sdlinput.hpp>
 #include <guichan/exception.hpp>
 
 #include "beingmanager.h"
@@ -56,9 +55,12 @@
 #include "gui/menuwindow.h"
 #include "gui/minimap.h"
 #include "gui/ministatus.h"
+#include "gui/npcintegerdialog.h"
 #include "gui/npclistdialog.h"
+#include "gui/npcstringdialog.h"
 #include "gui/npc_text.h"
 #include "gui/ok_dialog.h"
+#include "gui/sdlinput.h"
 #include "gui/sell.h"
 #include "gui/setup.h"
 #include "gui/skill.h"
@@ -83,7 +85,6 @@
 #include "resources/imagewriter.h"
 
 extern Graphics *graphics;
-extern gcn::SDLInput *guiInput;
 
 class Map;
 
@@ -108,8 +109,10 @@ BuyDialog *buyDialog;
 SellDialog *sellDialog;
 BuySellDialog *buySellDialog;
 InventoryWindow *inventoryWindow;
+NpcIntegerDialog *npcIntegerDialog;
 NpcListDialog *npcListDialog;
 NpcTextDialog *npcTextDialog;
+NpcStringDialog *npcStringDialog;
 SkillDialog *skillDialog;
 Setup* setupWindow;
 Minimap *minimap;
@@ -188,7 +191,9 @@ void createGuiWindows(Network *network)
     buySellDialog = new BuySellDialog();
     inventoryWindow = new InventoryWindow();
     npcTextDialog = new NpcTextDialog();
+    npcIntegerDialog = new NpcIntegerDialog();
     npcListDialog = new NpcListDialog();
+    npcStringDialog = new NpcStringDialog();
     skillDialog = new SkillDialog();
     setupWindow = new Setup();
     minimap = new Minimap();
@@ -229,6 +234,7 @@ void createGuiWindows(Network *network)
  */
 void destroyGuiWindows()
 {
+    logger->setChatWindow(NULL);
     delete chatWindow;
     delete statusWindow;
     delete miniStatusWindow;
@@ -237,8 +243,10 @@ void destroyGuiWindows()
     delete sellDialog;
     delete buySellDialog;
     delete inventoryWindow;
+    delete npcIntegerDialog;
     delete npcListDialog;
     delete npcTextDialog;
+    delete npcStringDialog;
     delete skillDialog;
     delete setupWindow;
     delete minimap;
@@ -337,11 +345,14 @@ Game::~Game()
     joystick = NULL;
 }
 
-bool saveScreenshot(SDL_Surface *screenshot)
+static bool saveScreenshot()
 {
     static unsigned int screenshotCount = 0;
 
+    SDL_Surface *screenshot = graphics->getScreenshot();
+
     // Search for an unused screenshot name
+    std::stringstream filenameSuffix;
     std::stringstream filename;
     std::fstream testExists;
     bool found = false;
@@ -349,29 +360,37 @@ bool saveScreenshot(SDL_Surface *screenshot)
     do {
         screenshotCount++;
         filename.str("");
+        filenameSuffix.str("");
+        filename << PHYSFS_getUserDir();
 #if (defined __USE_UNIX98 || defined __FreeBSD__)
-        filename << PHYSFS_getUserDir() << ".tmw/";
+        filenameSuffix << ".tmw/";
 #elif defined __APPLE__
-        filename << PHYSFS_getUserDir() << "Desktop/";
+        filenameSuffix << "Desktop/";
 #endif
-        filename << "TMW_Screenshot_" << screenshotCount << ".png";
+        filenameSuffix << "TMW_Screenshot_" << screenshotCount << ".png";
+        filename << filenameSuffix.str();
         testExists.open(filename.str().c_str(), std::ios::in);
         found = !testExists.is_open();
         testExists.close();
     } while (!found);
 
-    if (ImageWriter::writePNG(screenshot, filename.str()))
+    const bool success = ImageWriter::writePNG(screenshot, filename.str());
+
+    if (success)
     {
         std::stringstream chatlogentry;
-        chatlogentry << "Screenshot saved to " << filename.str().c_str();
+        chatlogentry << "Screenshot saved to ~/" << filenameSuffix.str();
         chatWindow->chatLog(chatlogentry.str(), BY_SERVER);
-        return true;
     }
     else
     {
         chatWindow->chatLog("Saving screenshot failed!", BY_SERVER);
-        return false;
+        logger->log("Error: could not save screenshot.");
     }
+
+    SDL_FreeSurface(screenshot);
+
+    return success;
 }
 
 void Game::optionChanged(const std::string &name)
@@ -441,9 +460,9 @@ void Game::logic()
         {
             if (!disconnectedDialog)
             {
-                disconnectedDialog = new
-                    OkDialog("Network Error",
-                    "The connection to the server was lost, the program will now quit");
+                disconnectedDialog = new OkDialog("Network Error",
+                        "The connection to the server was lost, "
+                        "the program will now quit");
                 disconnectedDialog->addActionListener(&exitListener);
                 disconnectedDialog->requestMoveToTop();
             }
@@ -453,10 +472,8 @@ void Game::logic()
 
 void Game::handleInput()
 {
-    if (joystick != NULL)
-    {
+    if (joystick)
         joystick->update();
-    }
 
     // Events
     SDL_Event event;
@@ -489,14 +506,7 @@ void Game::handleInput()
                 {
                     case SDLK_p:
                         // Screenshot (picture, hence the p)
-                        {
-                            SDL_Surface *screenshot = graphics->getScreenshot();
-                            if (!saveScreenshot(screenshot))
-                            {
-                                logger->log("Error: could not save Screenshot.");
-                            }
-                            SDL_FreeSurface(screenshot);
-                        }
+                        saveScreenshot();
                         used = true;
                         break;
 
@@ -514,10 +524,14 @@ void Game::handleInput()
                         {
                             unsigned int deflt = player_relations.getDefault();
                             if (deflt & PlayerRelation::TRADE) {
-                                chatWindow->chatLog("Ignoring incoming trade requests", BY_SERVER);
+                                chatWindow->chatLog(
+                                        "Ignoring incoming trade requests",
+                                        BY_SERVER);
                                 deflt &= ~PlayerRelation::TRADE;
                             } else {
-                                chatWindow->chatLog("Accepting incoming trade requests", BY_SERVER);
+                                chatWindow->chatLog(
+                                        "Accepting incoming trade requests",
+                                        BY_SERVER);
                                 deflt |= PlayerRelation::TRADE;
                             }
 
@@ -613,6 +627,26 @@ void Game::handleInput()
                     {
                         setupWindow->action(gcn::ActionEvent(NULL, "cancel"));
                     }
+                    // Submits the text and proceeds to the next dialog
+                    else if (npcStringDialog->isVisible())
+                    {
+                        npcStringDialog->action(gcn::ActionEvent(NULL, "ok"));
+                    }
+                    // Proceed to the next dialog option, or close the window
+                    else if (npcTextDialog->isVisible())
+                    {
+                        npcTextDialog->action(gcn::ActionEvent(NULL, "ok"));
+                    }
+                    // Choose the currently highlighted dialogue option
+                    else if (npcListDialog->isVisible())
+                    {
+                        npcListDialog->action(gcn::ActionEvent(NULL, "ok"));
+                    }
+                    // Submits the text and proceeds to the next dialog
+                    else if (npcIntegerDialog->isVisible())
+                    {
+                        npcIntegerDialog->action(gcn::ActionEvent(NULL, "ok"));
+                    }
                     // Else, open the chat edit box
                     else
                     {
@@ -620,7 +654,7 @@ void Game::handleInput()
                         used = true;
                     }
                     break;
-                   // Quitting confirmation dialog
+                    // Quitting confirmation dialog
                 case SDLK_ESCAPE:
                     if (!exitConfirm) {
                         exitConfirm = new ConfirmDialog(
@@ -637,7 +671,8 @@ void Game::handleInput()
                 default:
                     break;
             }
-            if (keyboard.isEnabled() && !chatWindow->isInputFocused())
+            if (keyboard.isEnabled() && !chatWindow->isInputFocused()
+                && !npcStringDialog->isInputFocused())
             {
                 const int tKey = keyboard.getKeyIndex(event.key.keysym.sym);
                 // Do not activate shortcuts if tradewindow is visible
@@ -658,11 +693,12 @@ void Game::handleInput()
                 switch (tKey) {
                     case KeyboardConfig::KEY_PICKUP:
                         {
-                            FloorItem *item = floorItemManager->findByCoordinates(
-                                    player_node->mX, player_node->mY);
+                            FloorItem *item =
+                                floorItemManager->findByCoordinates(
+                                        player_node->mX, player_node->mY);
 
-                            // If none below the player, try the tile in front of
-                            // the player
+                            // If none below the player, try the tile in front
+                            // of the player
                             if (!item) {
                                 Uint16 x = player_node->mX;
                                 Uint16 y = player_node->mY;
@@ -675,7 +711,8 @@ void Game::handleInput()
                                 if (player_node->getDirection() & Being::RIGHT)
                                     x++;
 
-                                item = floorItemManager->findByCoordinates(x, y);
+                                item = floorItemManager->findByCoordinates(
+                                        x, y);
                             }
 
                             if (item)
@@ -702,15 +739,34 @@ void Game::handleInput()
                             debugWindow->setVisible(false);
                         }
                         break;
-                    case KeyboardConfig::KEY_WINDOW_STATUS: requestedWindow = statusWindow; break;
-                    case KeyboardConfig::KEY_WINDOW_INVENTORY: requestedWindow = inventoryWindow; break;
-                    case KeyboardConfig::KEY_WINDOW_EQUIPMENT: requestedWindow = equipmentWindow; break;
-                    case KeyboardConfig::KEY_WINDOW_SKILL: requestedWindow = skillDialog; break;
-                    case KeyboardConfig::KEY_WINDOW_MINIMAP: requestedWindow = minimap; break;
-                    case KeyboardConfig::KEY_WINDOW_CHAT: requestedWindow = chatWindow; break;
-                    case KeyboardConfig::KEY_WINDOW_SHORTCUT: requestedWindow = itemShortcutWindow; break;
-                    case KeyboardConfig::KEY_WINDOW_SETUP: requestedWindow = setupWindow; break;
-                    case KeyboardConfig::KEY_WINDOW_DEBUG: requestedWindow = debugWindow; break;
+
+                    case KeyboardConfig::KEY_WINDOW_STATUS:
+                        requestedWindow = statusWindow;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_INVENTORY:
+                        requestedWindow = inventoryWindow;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_EQUIPMENT:
+                        requestedWindow = equipmentWindow;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_SKILL:
+                        requestedWindow = skillDialog;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_MINIMAP:
+                        requestedWindow = minimap;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_CHAT:
+                        requestedWindow = chatWindow;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_SHORTCUT:
+                        requestedWindow = itemShortcutWindow;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_SETUP:
+                        requestedWindow = setupWindow;
+                        break;
+                    case KeyboardConfig::KEY_WINDOW_DEBUG:
+                        requestedWindow = debugWindow;
+                        break;
                 }
             }
 
@@ -747,11 +803,11 @@ void Game::handleInput()
         }
 
     } // End while
+
     // If the user is configuring the keys then don't respond.
     if (!keyboard.isEnabled())
-    {
-       return;
-    }
+        return;
+
     // Moving player around
     if (player_node->mAction != Being::DEAD &&
         current_npc == 0 &&
@@ -836,8 +892,8 @@ void Game::handleInput()
         if (keyboard.isKeyActive(keyboard.KEY_TARGET_CLOSEST)
                 || (joystick && joystick->buttonPressed(3)))
         {
-            Being *target =
-                beingManager->findNearestLivingBeing(x, y, 20, Being::MONSTER);
+            Being *target = beingManager->findNearestLivingBeing(
+                    x, y, 20, Being::MONSTER);
 
             if (target)
             {
