@@ -1,40 +1,30 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <algorithm>
 
-#include <guichan/graphics.hpp>
-#include <guichan/imagefont.hpp>
-#include <guichan/mouseinput.hpp>
-
 #include "browserbox.h"
+
 #include "linkhandler.h"
-
-#ifdef USE_OPENGL
-#include "../configuration.h"
-#include "../resources/resourcemanager.h"
-
-int BrowserBox::instances = 0;
-gcn::ImageFont* BrowserBox::browserFont = NULL;
-#endif
+#include "truetypefont.h"
 
 BrowserBox::BrowserBox(unsigned int mode):
     gcn::Widget(),
@@ -46,35 +36,10 @@ BrowserBox::BrowserBox(unsigned int mode):
 {
     setFocusable(true);
     addMouseListener(this);
-
-#ifdef USE_OPENGL
-    if (config.getValue("opengl", 0.0f)) {
-        if (instances == 0) {
-            browserFont = new gcn::ImageFont(
-                    "graphics/gui/browserfont.png",
-                    " abcdefghijklmnopqrstuvwxyz"
-                    "ABCDEFGHIJKLMNOPQRSTUVWXYZ01234567"
-                    "89:@!\"$%&/=?^+*#[]{}()<>_;'.,\\|-~`"
-                    "륣");
-        }
-        setFont(browserFont);
-        instances++;
-    }
-#endif
 }
 
 BrowserBox::~BrowserBox()
 {
-#ifdef USE_OPENGL
-    instances--;
-
-    if (instances == 0)
-    {
-        // Clean up static resource font
-        delete browserFont;
-        browserFont = NULL;
-    }
-#endif
 }
 
 void BrowserBox::setLinkHandler(LinkHandler* linkHandler)
@@ -103,7 +68,7 @@ void BrowserBox::addRow(const std::string &row)
     std::string newRow;
     BROWSER_LINK bLink;
     int idx1, idx2, idx3;
-    gcn::ImageFont *font = dynamic_cast<gcn::ImageFont*>(getFont());
+    TrueTypeFont *font = static_cast<TrueTypeFont*>(getFont());
 
     // Use links and user defined colors
     if (mUseLinksAndUserColors)
@@ -175,18 +140,19 @@ void BrowserBox::addRow(const std::string &row)
 
     if (mMode == AUTO_WRAP)
     {
-        unsigned int j, y = 0;
+        unsigned int y = 0;
         unsigned int nextChar;
-        char hyphen = '~';
+        const char *hyphen = "~";
         int hyphenWidth = font->getWidth(hyphen);
         int x = 0;
 
         for (TextRowIterator i = mTextRows.begin(); i != mTextRows.end(); i++)
         {
             std::string row = *i;
-            for (j = 0; j < row.size(); j++)
+            for (unsigned int j = 0; j < row.size(); j++)
             {
-                x += font->getWidth(row.at(j));
+                std::string character = row.substr(j, 1);
+                x += font->getWidth(character);
                 nextChar = j + 1;
 
                 // Wraping between words (at blank spaces)
@@ -297,10 +263,9 @@ BrowserBox::draw(gcn::Graphics *graphics)
         }
     }
 
-    unsigned int j;
     int x = 0, y = 0;
     int wrappedLines = 0;
-    gcn::ImageFont *font = dynamic_cast<gcn::ImageFont*>(getFont());
+    TrueTypeFont *font = static_cast<TrueTypeFont*>(getFont());
 
     graphics->setColor(BLACK);
     for (TextRowIterator i = mTextRows.begin(); i != mTextRows.end(); i++)
@@ -308,17 +273,45 @@ BrowserBox::draw(gcn::Graphics *graphics)
         int selColor = BLACK;
         int prevColor = selColor;
         std::string row = *(i);
+        bool wrapped = false;
         x = 0;
 
-        for (j = 0; j < row.size(); j++)
+        // Check for separator lines
+        if (row.find("---", 0) == 0)
         {
-            if ( (mUseLinksAndUserColors && (j + 3) <= row.size()) ||
-                    (!mUseLinksAndUserColors && (j == 0)) )
+            for (x = 0; x < getWidth(); x++)
+            {
+                font->drawString(graphics, "-", x, y);
+                x += font->getWidth("-") - 2;
+            }
+            y += font->getHeight();
+            continue;
+        }
+
+        // TODO: Check if we must take texture size limits into account here
+        // TODO: Check if some of the O(n) calls can be removed
+        for (std::string::size_type start = 0, end = std::string::npos;
+                start != std::string::npos;
+                start = end, end = std::string::npos)
+        {
+            // Wrapped line continuation shall be indented
+            if (wrapped)
+            {
+                y += font->getHeight();
+                x = 15;
+            }
+
+            // "Tokenize" the string at control sequences
+            if (mUseLinksAndUserColors)
+                end = row.find("##", start + 1);
+
+            if (mUseLinksAndUserColors ||
+                    (!mUseLinksAndUserColors && (start == 0)))
             {
                 // Check for color change in format "##x", x = [L,P,0..9]
-                if ((row.at(j) == '#') && (row.at(j + 1) == '#'))
+                if (row.find("##", start) == start && row.size() > start + 2)
                 {
-                    switch (row.at(j + 2))
+                    switch (row.at(start + 2))
                     {
                         case 'L': // Link color
                             prevColor = selColor;
@@ -368,71 +361,64 @@ BrowserBox::draw(gcn::Graphics *graphics)
                             prevColor = selColor;
                             selColor = BLACK;
                     }
-                    j += 3;
-
-                    if (j == row.size())
-                    {
-                        break;
-                    }
+                    start += 3;
                 }
                 graphics->setColor(gcn::Color(selColor));
             }
 
-            // Check for line separators in format "---"
-            if (row == "---")
-            {
-                for (x = 0; x < getWidth(); x++)
-                {
-                    font->drawGlyph(graphics, '-', x, y);
-                    x += font->getWidth('-') - 2;
-                }
-                break;
-            }
-            // Draw each char
-            else
-            {
-                font->drawGlyph(graphics, row.at(j), x, y);
-                x += font->getWidth(row.at(j));
+            std::string::size_type len =
+                end == std::string::npos ? end : end - start;
+            std::string part = row.substr(start, len);
 
-                // Auto wrap mode
-                if (mMode == AUTO_WRAP)
-                {
-                    unsigned int nextChar = j + 1;
-                    char hyphen = '~';
-                    int hyphenWidth =  font->getWidth(hyphen);
+            // Auto wrap mode
+            if (mMode == AUTO_WRAP &&
+                    (x + font->getWidth(part.c_str()) + 10) > getWidth())
+            {
+                bool forced = false;
+                char const *hyphen = "~";
+                int hyphenWidth =  font->getWidth(hyphen);
 
-                    // Wraping between words (at blank spaces)
-                    if ((nextChar < row.size()) && (row.at(nextChar) == ' '))
+                /* FIXME: This code layout makes it easy to crash remote
+                   clients by talking garbage. Forged long utf-8 characters
+                   will cause either a buffer underflow in substr or an
+                   infinite loop in the main loop. */
+                do
+                {
+                    if (!forced)
+                        end = row.rfind(" ", end);
+
+                    // Check if we have to (stupidly) force-wrap
+                    if (end == std::string::npos || end <= start)
                     {
-                        int nextSpacePos = row.find(" ", (nextChar + 1));
-                        if (nextSpacePos <= 0)
-                        {
-                            nextSpacePos = row.size() - 1;
-                        }
-                        int nextWordWidth = font->getWidth(
-                                row.substr(nextChar,
-                                    (nextSpacePos - nextChar)));
-
-                        if ((x + nextWordWidth + 10) > getWidth())
-                        {
-                            x = 15; // Ident in new line
-                            y += font->getHeight();
-                            wrappedLines++;
-                            j++;
-                        }
+                        forced = true;
+                        end = row.size();
+                        x += hyphenWidth * 2; // Account for the wrap-notifier
+                        continue;
                     }
 
-                    // Wrapping looong lines (brutal force)
-                    else if ((x + 2 * hyphenWidth) > getWidth())
-                    {
-                        font->drawGlyph(graphics, hyphen,
-                                getWidth() - hyphenWidth, y);
-                        x = 15; // Ident in new line
-                        y += font->getHeight();
-                        wrappedLines++;
-                    }
+                    // Skip to the start of the current character
+                    while ((row[end] & 192) == 128)
+                        end--;
+                    end--; // And then to the last byte of the previous one
+
+                    part = row.substr(start, end - start + 1);
+                } while ((x + font->getWidth(part.c_str()) + 10) > getWidth());
+
+                if (forced)
+                {
+                    x -= hyphenWidth; // Remove the wrap-notifier accounting
+                    font->drawString(graphics, hyphen,
+                            getWidth() - hyphenWidth, y);
+                    end++; // Skip to the next character
                 }
+                else
+                    end += 2; // Skip to after the space
+
+                wrapped = true;
+                wrappedLines++;
             }
+            font->drawString(graphics, part, x, y);
+            x += font->getWidth(part.c_str());
         }
         y += font->getHeight();
         setHeight((mTextRows.size() + wrappedLines) * font->getHeight());
