@@ -1,32 +1,32 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef __TMW_BROWSERBOX_H__
-#define __TMW_BROWSERBOX_H__
+#ifndef BROWSERBOX_H
+#define BROWSERBOX_H
 
 #include <iosfwd>
 #include <vector>
 
-#include <guichan/widget.hpp>
 #include <guichan/mouselistener.hpp>
+#include <guichan/widget.hpp>
 
 #include "../guichanfwd.h"
 #include "../main.h"
@@ -162,11 +162,6 @@ class BrowserBox : public gcn::Widget, public gcn::MouseListener
         bool mUseLinksAndUserColors;
         int mSelectedLink;
         unsigned int mMaxRows;
-
-#ifdef USE_OPENGL
-        static int instances;      /**< Number of Window instances */
-        static gcn::ImageFont* browserFont;
-#endif
 };
 
 #endif
