@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -25,10 +25,9 @@
 #include <guichan/image.hpp>
 #include <guichan/imagefont.hpp>
 
-// Should stay here because of Guichan being sensitive to headers order
-#include <guichan/sdl/sdlinput.hpp>
-
 #include "focushandler.h"
+#include "sdlinput.h"
+#include "truetypefont.h"
 #include "viewport.h"
 #include "window.h"
 #include "windowcontainer.h"
@@ -44,16 +43,14 @@
 #include "../resources/imageloader.h"
 
 // Guichan stuff
-Gui *gui;
-Viewport *viewport;                    /**< Viewport on the map. */
-gcn::SDLInput *guiInput;               /**< GUI input. */
+Gui *gui = 0;
+Viewport *viewport = 0;               /**< Viewport on the map. */
+SDLInput *guiInput = 0;
 
 // Fonts used in showing hits
-gcn::Font *hitRedFont;
-gcn::Font *hitBlueFont;
-gcn::Font *hitYellowFont;
-// Font used to display speech and player names
-gcn::Font *speechFont;
+gcn::Font *hitRedFont = 0;
+gcn::Font *hitBlueFont = 0;
+gcn::Font *hitYellowFont = 0;
 
 class GuiConfigListener : public ConfigListener
 {
@@ -89,7 +86,7 @@ Gui::Gui(Graphics *graphics):
     gcn::Image::setImageLoader(&imageLoader);
 
     // Set input
-    guiInput = new gcn::SDLInput();
+    guiInput = new SDLInput;
     setInput(guiInput);
 
     // Set focus handler
@@ -104,39 +101,17 @@ Gui::Gui(Graphics *graphics):
     Window::setWindowContainer(guiTop);
     setTop(guiTop);
 
-    // Set global font (based on ISO-8859-15)
-    try {
-        mGuiFont = new gcn::ImageFont("graphics/gui/sansserif8.png",
-                " !\"#$%&'()*+,-./"
-                "0123456789:;<=>?"
-                "@ABCDEFGHIJKLMNO"
-                "PQRSTUVWXYZ[\\]^_"
-                "`abcdefghijklmno"
-                "pqrstuvwxyz{|}~|"
-                ""
-                ""
-                ""
-                ""
-                ""
-                ""
-                );
-    }
-    catch (gcn::Exception e)
-    {
-        logger->error("Unable to load sansserif8.png!");
-    }
+    ResourceManager *resman = ResourceManager::getInstance();
 
-    // Set speech font
+    // Set global font
+    std::string path = resman->getPath("fonts/dejavusans.ttf");
     try {
-        speechFont = new gcn::ImageFont("graphics/gui/rpgfont_wider.png",
-                " abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
-                "0123456789.,!?-+/():;%&`'*#=[]\"<>{}^~|_@$\\"
-                "륣"
-                );
+        mGuiFont = new TrueTypeFont(path, 11);
     }
     catch (gcn::Exception e)
     {
-        logger->error("Unable to load rpgfont_wider.png!");
+        logger->error(std::string("Unable to load dejavusans.ttf: ")
+            + e.getMessage());
     }
 
     gcn::Widget::setGlobalFont(mGuiFont);
@@ -152,7 +127,8 @@ Gui::Gui(Graphics *graphics):
     }
     catch (gcn::Exception e)
     {
-        logger->error("Unable to load colored hits' fonts!");
+        logger->error(std::string("Unable to load colored hits' fonts: ")
+                + e.getMessage());
     }
 
     // Initialize mouse cursor and listen for changes to the option
@@ -181,7 +157,6 @@ Gui::~Gui()
         mMouseCursors->decRef();
 
     delete mGuiFont;
-    delete speechFont;
     delete viewport;
     delete getTop();
 
