@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -81,3 +81,22 @@ void RadioButton::drawBox(gcn::Graphics* graphics)
         static_cast<Graphics*>(graphics)->drawImage(box, 2, 2);
     }
 }
+
+void RadioButton::draw(gcn::Graphics* graphics)
+{
+
+    graphics->pushClipArea(gcn::Rectangle(1,
+                                    1,
+                                    getWidth() - 1,
+                                    getHeight() - 1));
+
+    drawBox(graphics);
+
+    graphics->popClipArea();
+
+    graphics->setFont(getFont());
+    graphics->setColor(getForegroundColor());
+
+    int h = getHeight() + getHeight() / 2;
+    graphics->drawText(getCaption(), h - 2, 0);
+}
