@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -62,6 +62,32 @@ struct Location
     MetaTile *tile;
 };
 
+TileAnimation::TileAnimation(Animation *ani):
+    mAnimation(ani),
+    mLastImage(NULL)
+{
+}
+
+void TileAnimation::update()
+{
+    //update animation
+    mAnimation.update(1);
+
+    // exchange images
+    Image *img = mAnimation.getCurrentImage();
+    if (img != mLastImage)
+    {
+        for (std::list<std::pair<MapLayer*, int> >::iterator i = mAffected.begin();
+             i != mAffected.end();
+             i++)
+        {
+            i->first->setTile(i->second, img);
+        }
+        mLastImage = img;
+    }
+
+}
+
 MapLayer::MapLayer(int x, int y, int width, int height, bool isFringeLayer):
     mX(x), mY(y),
     mWidth(width), mHeight(height),
@@ -79,7 +105,7 @@ MapLayer::~MapLayer()
 
 void MapLayer::setTile(int x, int y, Image *img)
 {
-    mTiles[x + y * mWidth] = img;
+    setTile(x + y * mWidth, img);
 }
 
 Image* MapLayer::getTile(int x, int y) const
@@ -155,6 +181,7 @@ Map::~Map()
     delete_all(mLayers);
     delete_all(mTilesets);
     delete_all(mOverlays);
+    delete_all(mTileAnimations);
 }
 
 void Map::initializeOverlays()
@@ -201,6 +228,17 @@ bool spriteCompare(const Sprite *a, const Sprite *b)
     return a->getPixelY() < b->getPixelY();
 }
 
+void Map::update()
+{
+    //update animated tiles
+    for (std::map<int, TileAnimation*>::iterator iAni = mTileAnimations.begin();
+         iAni != mTileAnimations.end();
+         iAni++)
+    {
+        iAni->second->update();
+    }
+}
+
 void Map::draw(Graphics *graphics, int scrollX, int scrollY)
 {
     int endPixelY = graphics->getHeight() + scrollY + mTileHeight - 1;
@@ -216,6 +254,7 @@ void Map::draw(Graphics *graphics, int scrollX, int scrollY)
     // Make sure sprites are sorted
     mSprites.sort(spriteCompare);
 
+    // draw the game world
     Layers::const_iterator layeri = mLayers.begin();
     for (; layeri != mLayers.end(); ++layeri) {
         (*layeri)->draw(graphics,
@@ -485,7 +524,7 @@ Path Map::findPath(int startX, int startY, int destX, int destY)
         while (pathX != startX || pathY != startY)
         {
             // Add the new path node to the start of the path list
-            path.push_front(PATH_NODE(pathX, pathY));
+            path.push_front(Position(pathX, pathY));
 
             // Find out the next parent
             MetaTile *tile = getMetaTile(pathX, pathY);
@@ -516,3 +555,14 @@ void Map::initializeParticleEffects(Particle* particleEngine)
         particleEngine->addEffect(i->file, i->x, i->y);
     }
 }
+
+TileAnimation* Map::getAnimationForGid(int gid)
+{
+    std::map<int, TileAnimation*>::iterator i = mTileAnimations.find(gid);
+    if (i == mTileAnimations.end())
+    {
+        return NULL;
+    } else {
+        return i->second;
+    }
+}
