@@ -1,26 +1,26 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#ifndef _TMW_OPENGLGRAPHICS_H
-#define _TMW_OPENGLGRAPHICS_H
+#ifndef OPENGLGRAPHICS_H
+#define OPENGLGRAPHICS_H
 
 #include "graphics.h"
 
@@ -31,6 +31,13 @@ class OpenGLGraphics : public Graphics
 
         ~OpenGLGraphics();
 
+        /**
+         * Sets whether vertical refresh syncing is enabled. Takes effect after
+         * the next call to setVideoMode(). Only implemented on MacOS for now.
+         */
+        void setSync(bool sync);
+        bool getSync() const { return mSync; }
+
         bool setVideoMode(int w, int h, int bpp, bool fs, bool hwaccel);
 
         bool drawImage(Image *image,
@@ -72,6 +79,7 @@ class OpenGLGraphics : public Graphics
     private:
         bool mAlpha, mTexture;
         bool mColorAlpha;
+        bool mSync;
 };
 
 #endif
