@@ -1,21 +1,21 @@
 /*
  *  The Mana World
- *  Copyright 2004 The Mana World Development Team
+ *  Copyright (C) 2004  The Mana World Development Team
  *
  *  This file is part of The Mana World.
  *
- *  The Mana World is free software; you can redistribute it and/or modify
+ *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  any later version.
  *
- *  The Mana World is distributed in the hope that it will be useful,
+ *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with The Mana World; if not, write to the Free Software
+ *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
@@ -30,6 +30,7 @@
 #include "../log.h"
 
 #include "../utils/dtor.h"
+#include "../utils/gettext.h"
 #include "../utils/xml.h"
 
 namespace
@@ -53,8 +54,8 @@ void ItemDB::load()
     mUnknown = new ItemInfo();
     mUnknown->setName("Unknown item");
     mUnknown->setImageName("");
-    mUnknown->setSprite("error.xml", 0);
-    mUnknown->setSprite("error.xml", 1);
+    mUnknown->setSprite("error.xml", GENDER_MALE);
+    mUnknown->setSprite("error.xml", GENDER_FEMALE);
 
     XML::Document doc("items.xml");
     xmlNodePtr rootNode = doc.rootNode();
@@ -93,9 +94,9 @@ void ItemDB::load()
 
         if (id)
         {
-            ItemInfo *itemInfo = new ItemInfo();
+            ItemInfo *itemInfo = new ItemInfo;
             itemInfo->setImageName(image);
-            itemInfo->setName((name == "") ? "Unnamed" : name);
+            itemInfo->setName(name.empty() ? _("Unnamed") : name);
             itemInfo->setDescription(description);
             itemInfo->setEffect(effect);
             itemInfo->setType(type);
@@ -172,12 +173,12 @@ void loadSpriteRef(ItemInfo *itemInfo, xmlNodePtr node)
 
     if (gender == "male" || gender == "unisex")
     {
-        itemInfo->setSprite(filename, 0);
+        itemInfo->setSprite(filename, GENDER_MALE);
     }
 
     if (gender == "female" || gender == "unisex")
     {
-        itemInfo->setSprite(filename, 1);
+        itemInfo->setSprite(filename, GENDER_FEMALE);
     }
 }
 
